==> zwave-js-server-python-0.26.0.tar.gz: zwave-js-server-python-0.26.0/zwave_js_server/model/device_class.py <==
"""
Model for a Zwave Node's device class.

https://zwave-js.github.io/node-zwave-js/#/api/node?id=deviceclass
"""

from dataclasses import dataclass
from typing import List, TypedDict


class DeviceClassItemDataType(TypedDict):
    """Represent a device class data dict type."""

    key: int
    label: str


class DeviceClassDataType(TypedDict):
    """Represent a device class data dict type."""

    basic: DeviceClassItemDataType
    generic: DeviceClassItemDataType
    specific: DeviceClassItemDataType
    mandatorySupportedCCs: List[int]
    mandatoryControlledCCs: List[int]


@dataclass
class DeviceClassItem:
    """Model for a DeviceClass item (e.g. basic or generic)."""

    key: int
    label: str


class DeviceClass:
    """Model for a Zwave Node's device class."""

    def __init__(self, data: DeviceClassDataType) -> None:
        """Initialize."""
        self.data = data

    @property
    def basic(self) -> DeviceClassItem:
        """Return basic DeviceClass."""
        return DeviceClassItem(**self.data["basic"])

    @property
    def generic(self) -> DeviceClassItem:
        """Return generic DeviceClass."""
        return DeviceClassItem(**self.data["generic"])

    @property
    def specific(self) -> DeviceClassItem:
        """Return specific DeviceClass."""
        return DeviceClassItem(**self.data["specific"])

    @property
    def mandatory_supported_ccs(self) -> List[int]:
        """Return list of mandatory Supported CC id's."""
        return self.data["mandatorySupportedCCs"]

    @property
    def mandatory_controlled_ccs(self) -> List[int]:
        """Return list of mandatory Controlled CC id's."""
        return self.data["mandatoryControlledCCs"]

==> zwave-js-server-python_0.67.0.orig.tar.gz: zwave-js-server-python-0.67.0/zwave_js_server/model/device_class.py <==
"""
Model for a Zwave Node's device class.

https://zwave-js.github.io/node-zwave-js/#/api/node?id=deviceclass
"""

from __future__ import annotations

from dataclasses import dataclass
from typing import TypedDict


class DeviceClassItemDataType(TypedDict):
    """Represent a device class data dict type."""

    key: int
    label: str


class DeviceClassDataType(TypedDict):
    """Represent a device class data dict type."""

    basic: DeviceClassItemDataType
    generic: DeviceClassItemDataType
    specific: DeviceClassItemDataType


@dataclass
class DeviceClassItem:
    """Model for a DeviceClass item (e.g. basic or generic)."""

    key: int
    label: str


class DeviceClass:
    """Model for a Zwave Node's device class."""

    def __init__(self, data: DeviceClassDataType) -> None:
        """Initialize."""
        self._basic = DeviceClassItem(
            key=data["basic"]["key"],
            label=data["basic"]["label"],
        )
        self._generic = DeviceClassItem(
            key=data["generic"]["key"],
            label=data["generic"]["label"],
        )
        self._specific = DeviceClassItem(
            key=data["specific"]["key"],
            label=data["specific"]["label"],
        )

    @property
    def basic(self) -> DeviceClassItem:
        """Return basic DeviceClass."""
        return self._basic

    @property
    def generic(self) -> DeviceClassItem:
        """Return generic DeviceClass."""
        return self._generic

    @property
    def specific(self) -> DeviceClassItem:
        """Return specific DeviceClass."""
        return self._specific
